//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[isWind](is-wind.md)

# isWind

[common]\
val [Tile](-tile/index.md).[isWind](is-wind.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否为风牌
